# -*- coding: utf-8 -*-

import os

from .app import get_app


"""Top-level package for Tengu."""

__author__ = """Barak Avrahami"""
__email__ = 'barak1345@gmail.com'
__version__ = '0.1.12'

app = get_app()
